Index: trunk/psModules/src/config/pmConfigRun.h
===================================================================
--- trunk/psModules/src/config/pmConfigRun.h	(revision 23268)
+++ trunk/psModules/src/config/pmConfigRun.h	(revision 23447)
@@ -6,6 +6,12 @@
 #include <pmFPAfile.h>
 
-/// Add a file to the list of files used in the run-time information
-bool pmConfigRunFileAdd(
+/// Add a file to the list of files read in the run-time information
+bool pmConfigRunFileAddRead(
+    pmConfig *config,                   ///< Configuration
+    const pmFPAfile *file               ///< File to add
+    );
+
+/// Add a file to the list of files written in the run-time information
+bool pmConfigRunFileAddWrite(
     pmConfig *config,                   ///< Configuration
     const pmFPAfile *file               ///< File to add
